{ inputs, pkgs, ... }:
let

  k-vars = ''
(defvar
  tap-timeout   150
  hold-timeout  200)
'';
  shared-alias = ''
(defalias
  supesc (tap-hold-press $tap-timeout $hold-timeout esc lmet)

  hyper (multi lsft lctl lalt lmet)

  ;; ctrl return
  ctrl-ret (tap-hold-press $tap-timeout $hold-timeout ret lctl)

  ;; layer mods
  spcnav (tap-hold $tap-timeout 300 spc (layer-while-held navigation))

  ;; space cadet shift
  sp-lsft (tap-hold-press $tap-timeout $hold-timeout S-9 lsft)
  sp-rsft (tap-hold-press $tap-timeout $hold-timeout S-0 lsft)

  ;; home-row mods
  a (tap-hold $tap-timeout $hold-timeout a lshift)
  s (tap-hold $tap-timeout $hold-timeout s lalt)
  d (tap-hold $tap-timeout $hold-timeout d lctrl)
  ;; f (tap-hold-press $tap-timeout $hold-timeout f )
)
'';

in
{
  environment.systemPackages = [
    pkgs.kanata
  ];

  # Add the Kanata service user to necessary groups
  systemd.services.kanata-razer.serviceConfig = {
    SupplementaryGroups = [
      "input"
      "uinput"
      "openrazer"
    ];
  };

  services.kanata = {
    enable = true;

    keyboards = {
      raise = {
        devices = [ "/dev/input/by-id/usb-DYGMA_RAISE2_012310010BFAE7C9-if02-event-kbd" ];
        extraDefCfg = ''
process-unmapped-keys yes
concurrent-tap-hold yes
allow-hardware-repeat false
'';

        config = ''
(defsrc
 esc   1    2    3    4    5    6    7    8    9    0    -    =  bspc
 tab  q    w    e    r    t    y    u    i    o    p    [    ]    \
 caps a    s    d    f    g    h    j    k    l    ;    '    ret

 lsft z    x    c    v    b    n    m    ,    .    /    rsft
 lctl lmet lalt f23     ins  spc       f24 ralt rmet menu rctrl
                        f19 f20 f21 f22)

${k-vars}

${shared-alias}

(defalias
  controls (layer-while-held media-controls))

(deflayer qwerty
          grv  1    2    3    4    5    6    7    8    9    0    -    = bspc
          tab  q    w    e    r    t    y    u    i    o    p    [    ]  \
          @supesc @a    @s    @d    f    g    h    j    k    l    ;    '    ret
          @sp-lsft z    x    c    v    b    n    m    ,    .    /    @sp-rsft
          @supesc @controls lalt lctrl   @spcnav      @spcnav    rctrl ralt @controls @hyper @supesc
                             bspc ret ret del)

(deflayer navigation
          grv  f1    f2    f3    f4    f5    f6    f7    f8    f9    f10    f11   f12   bspc
          tab  q    w    e    r    t    home    pgdn    pgup    end    p    [    ]  prtsc
          _ @a    @s    @d    f    g    left down up    right    ;    '    ret
          _ z    x    c    v    b    n    m    ,    .    /    up
          _ _ _ _ _    _         _ _    left down right
                         _ _ _ _)

(deflayer media-controls
          grv VolumeMute  VolumeDown  VolumeUp  f4  MediaTrackPrevious  MediaPlayPause MediaTrackNext    f8    f9    f10    f11   f12   bspc
          tab  q    w    e    r    t    home    pgdn    pgup    end    p    [    ]  \
          _ @a    @s    @d    f    g    MediaTrackPrevious  VolumeDown  VolumeUp   MediaTrackNext    MediaPlayPause    '    ret
          _ z    x    c    v    b    n    m    ,    .    /    _
          _ _ _ _ _    _         _ _     _ _ _
                         _ _ _ _)

'';
      };

      razer = {
        devices = [ "/dev/input/by-id/usb-Razer_Razer_Blade-event-kbd"
                    "/dev/input/by-id/usb-Razer_Razer_Blade-if01-event-kbd" ];
        extraDefCfg = ''
process-unmapped-keys yes
concurrent-tap-hold yes
allow-hardware-repeat false
'';
        config = ''
(defsrc
  grv  1    2    3    4    5    6    7    8    9    0    -    =    bspc
  tab  q    w    e    r    t    y    u    i    o    p    [    ]    \
  caps a    s    d    f    g    h    j    k    l    ;    '    ret
  lsft z    x    c    v    b    n    m    ,    .    /    rsft
  lctrl lmet lalt           spc            ralt rctrl)

${k-vars}

${shared-alias}

(deflayer qwerty
  grv  1    2    3    4    5    6    7    8    9    0    -    =    bspc
  tab  q    w    e    r    t    y    u    i    o    p    [    ]    \
  @supesc  @a    @s    @d    f    g    h    j    k    l    ;    '    ret
  @sp-lsft z    x    c    v    b    n    m    ,    .    /    @sp-rsft
  @supesc lalt @ctrl-ret     @spcnav            @ctrl-ret ralt)

(deflayer navigation
          grv  1    2    3    4    5    6    7    8    9    0    -    =  bspc
          tab  q    w    e    r    t    home    pgdn    pgup    end    p    [    ]  \
          _   _   _   _    _    _    left   down   up   right    ;    '    ret
          @sp-lsft z    x    c    v    b    n    m    ,    .    /    @sp-rsft
          _ _ _        _            _ _)
'';
      };
    };
  };
}
